@@ -1,9 +1,7 @@
 {-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, GeneralizedNewtypeDeriving, FlexibleContexts, TypeOperators #-}
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE MonoLocalBinds #-}
-#if __GLASGOW_HASKELL__ >= 702
 {-# LANGUAGE Trustworthy #-}
-#endif
 
 -----------------------------------------------------------------------------
 -- |
@@ -24,13 +22,12 @@ module Data.Semigroup.Monad
     ) where
 
 import Control.Monad (liftM, liftM2)
-#if __GLASGOW_HASKELL__ < 710
-import Control.Applicative (Applicative(..))
-import Data.Monoid (Monoid(..))
-#endif
-import Data.Semigroup (Semigroup(..))
 import Data.Semigroup.Reducer (Reducer(..))
 
+#if !(MIN_VERSION_base(4,11,0))
+import Data.Semigroup (Semigroup(..))
+#endif
+
 -- | A 'Action' uses an glues together monadic actions with (>>)
 --   in the manner of 'mapM_' from "Data.Foldable". Any values returned by
 --   reduced actions are discarded.
@@ -41,7 +38,9 @@ instance Monad f => Semigroup (Action f) where
 
 instance Monad f => Monoid (Action f) where
   mempty = Action (return ())
+#if !(MIN_VERSION_base(4,11,0))
   Action a `mappend` Action b = Action (a >> b)
+#endif
 
 instance Monad f => Reducer (f a) (Action f) where
   unit a            = Action (a >> return ())
@@ -63,7 +62,9 @@ instance (Monad f, Semigroup m) => Semigroup (Mon f m) where
 
 instance (Monad f, Monoid m) => Monoid (Mon f m) where
   mempty = return mempty
+#if !(MIN_VERSION_base(4,11,0))
   mappend = liftM2 mappend
+#endif
 
 instance (Monad f, Reducer c m) => Reducer (f c) (Mon f m) where
   unit = liftM unit . Mon
